@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
 import os
 import sys
 
-import semantic_release  # noqa
-
 sys.path.insert(0, os.path.abspath("."))
 sys.path.insert(0, os.path.abspath(".."))
 
+import semantic_release  # noqa: E402
+
 # -- General configuration ------------------------------------------------
 
 extensions = [
@@ -14,54 +13,37 @@ extensions = [
     "sphinx.ext.doctest",
     "sphinx.ext.coverage",
     "sphinx.ext.viewcode",
+    "sphinxcontrib.apidoc",
 ]
 
 templates_path = ["_templates"]
 source_suffix = ".rst"
 master_doc = "index"
 project = "python-semantic-release"
-copyright = "2020, Rolf Erik Lekang"
+copyright = "2020, Rolf Erik Lekang"  # noqa: A001
 
 version = semantic_release.__version__
 release = semantic_release.__version__
 
-# language = None
-# today = ''
-# today_fmt = '%B %d, %Y'
 
 exclude_patterns = ["_build"]
 pygments_style = "sphinx"
-html_theme = "alabaster"
-html_static_path = ["_static"]
+html_theme = "furo"
 htmlhelp_basename = "python-semantic-releasedoc"
 
 
 # -- Automatically run sphinx-apidoc --------------------------------------
 
-
-def run_apidoc(_):
-    from sphinx import apidoc
-
-    docs_path = os.path.dirname(__file__)
-    apidoc_path = os.path.join(docs_path, "api")
-    module_path = os.path.join(docs_path, "..", "semantic_release")
-
-    apidoc.main(
-        [
-            "--force",
-            "--module-first",
-            "--separate",
-            "-d",
-            "3",
-            "-o",
-            apidoc_path,
-            module_path,
-        ]
-    )
+docs_path = os.path.dirname(__file__)
+apidoc_output_dir = os.path.join(docs_path, "api")
+apidoc_module_dir = os.path.join(docs_path, "..", "semantic_release")
+apidoc_separate_modules = True
+apidoc_module_first = True
+apidoc_extra_args = ["-d", "3"]
 
 
-def setup(app):
-    app.connect("builder-inited", run_apidoc)
+def setup(app):  # noqa: ARG001,ANN001,ANN201
+    pass
 
 
 # -- Options for LaTeX output ---------------------------------------------
