@@ -7,13 +7,23 @@ from collections.abc import Mapping
 from dataclasses import dataclass, is_dataclass
 from enum import Enum
 from pathlib import Path
-from typing import Any, ClassVar, Dict, List, Optional, Tuple, Type, Union
+from typing import Any, ClassVar, Dict, List, Literal, Optional, Tuple, Type, Union
 
-from git import Actor
+from git import Actor, InvalidGitRepositoryError
 from git.repo.base import Repo
 from jinja2 import Environment
-from pydantic import BaseModel, Field, RootModel, ValidationError, model_validator
-from typing_extensions import Annotated, Literal
+from pydantic import (
+    BaseModel,
+    Field,
+    RootModel,
+    ValidationError,
+    field_validator,
+    model_validator,
+)
+
+# typing_extensions is for Python 3.8, 3.9, 3.10 compatibility
+from typing_extensions import Annotated, Self
+from urllib3.util.url import parse_url
 
 from semantic_release import hvcs
 from semantic_release.changelog import environment
@@ -29,8 +39,15 @@ from semantic_release.commit_parser import (
     TagCommitParser,
 )
 from semantic_release.const import COMMIT_MESSAGE, DEFAULT_COMMIT_AUTHOR, SEMVER_REGEX
-from semantic_release.errors import InvalidConfiguration, NotAReleaseBranch
+from semantic_release.errors import (
+    DetachedHeadGitError,
+    InvalidConfiguration,
+    MissingGitRemote,
+    NotAReleaseBranch,
+    ParserLoadError,
+)
 from semantic_release.helpers import dynamic_import
+from semantic_release.hvcs.remote_hvcs_base import RemoteHvcsBase
 from semantic_release.version import VersionTranslator
 from semantic_release.version.declaration import (
     PatternVersionDeclaration,
@@ -109,22 +126,87 @@ class BranchConfig(BaseModel):
 
 class RemoteConfig(BaseModel):
     name: str = "origin"
-    token: MaybeFromEnv = ""
-    url: Optional[MaybeFromEnv] = None
+    token: Optional[str] = None
+    url: Optional[str] = None
     type: HvcsClient = HvcsClient.GITHUB
     domain: Optional[str] = None
     api_domain: Optional[str] = None
     ignore_token_for_push: bool = False
+    insecure: bool = False
+
+    @field_validator("url", "domain", "api_domain", "token", mode="before")
+    @classmethod
+    def resolve_env_vars(cls, val: Any) -> str | None:
+        ret_val = (
+            val
+            if not isinstance(val, dict)
+            else (EnvConfigVar.model_validate(val).getvalue())
+        )
+        return ret_val or None
 
     @model_validator(mode="after")
-    def set_default_token(self) -> RemoteConfig:
+    def set_default_token(self) -> Self:
         # Set the default token name for the given VCS when no user input is given
-        if not self.token and self.type in _known_hvcs:
-            default_token_name = _known_hvcs[self.type].DEFAULT_ENV_TOKEN_NAME
-            if default_token_name:
-                self.token = EnvConfigVar(env=default_token_name)
+        if self.token:
+            return self
+        if self.type not in _known_hvcs:
+            return self
+        if env_token := self._get_default_token():
+            self.token = env_token
         return self
 
+    def _get_default_token(self) -> str | None:
+        hvcs_client_class = _known_hvcs[self.type]
+        default_hvcs_instance = hvcs_client_class("git@example.com:owner/project.git")
+        if not isinstance(default_hvcs_instance, RemoteHvcsBase):
+            return None
+
+        default_token_name = default_hvcs_instance.DEFAULT_ENV_TOKEN_NAME
+        if not default_token_name:
+            return None
+
+        return EnvConfigVar(env=default_token_name).getvalue()
+
+    @model_validator(mode="after")
+    def check_url_scheme(self) -> Self:
+        if self.url and isinstance(self.url, str):
+            self.check_insecure_flag(self.url, "url")
+
+        if self.domain and isinstance(self.domain, str):
+            self.check_insecure_flag(self.domain, "domain")
+
+        if self.api_domain and isinstance(self.api_domain, str):
+            self.check_insecure_flag(self.api_domain, "api_domain")
+
+        return self
+
+    def check_insecure_flag(self, url_str: str, field_name: str) -> None:
+        if not url_str:
+            return
+
+        scheme = parse_url(url_str).scheme
+        if scheme == "http" and not self.insecure:
+            raise ValueError(
+                str.join(
+                    "\n",
+                    [
+                        "Insecure 'HTTP' URL detected and disabled by default.",
+                        "Set the 'insecure' flag to 'True' to enable insecure connections.",
+                    ],
+                )
+            )
+
+        if scheme == "https" and self.insecure:
+            log.warning(
+                str.join(
+                    "\n",
+                    [
+                        f"'{field_name}' starts with 'https://' but the 'insecure' flag is set.",
+                        "This flag is only necessary for 'http://' URLs.",
+                    ],
+                )
+            )
+
 
 class PublishConfig(BaseModel):
     dist_glob_patterns: Tuple[str, ...] = ("dist/*",)
@@ -135,6 +217,7 @@ class RawConfig(BaseModel):
     assets: List[str] = []
     branches: Dict[str, BranchConfig] = {"main": BranchConfig()}
     build_command: Optional[str] = None
+    build_command_env: List[str] = []
     changelog: ChangelogConfig = ChangelogConfig()
     commit_author: MaybeFromEnv = EnvConfigVar(
         env="GIT_COMMIT_AUTHOR", default=DEFAULT_COMMIT_AUTHOR
@@ -146,31 +229,95 @@ class RawConfig(BaseModel):
     logging_use_named_masks: bool = False
     major_on_zero: bool = True
     allow_zero_version: bool = True
+    repo_dir: Annotated[Path, Field(validate_default=True)] = Path(".")
     remote: RemoteConfig = RemoteConfig()
+    no_git_verify: bool = False
     tag_format: str = "v{version}"
     publish: PublishConfig = PublishConfig()
     version_toml: Optional[Tuple[str, ...]] = None
     version_variables: Optional[Tuple[str, ...]] = None
 
+    @field_validator("repo_dir", mode="before")
+    @classmethod
+    def convert_str_to_path(cls, value: Any) -> Path:
+        if not isinstance(value, (str, Path)):
+            raise TypeError(f"Invalid type: {type(value)}, expected str or Path.")
+        return Path(value)
+
+    @field_validator("repo_dir", mode="after")
+    @classmethod
+    def verify_git_repo_dir(cls, dir_path: Path) -> Path:
+        try:
+            # Check for repository & walk up parent directories
+            with Repo(str(dir_path), search_parent_directories=True) as git_repo:
+                found_path = Path(
+                    git_repo.working_tree_dir or git_repo.working_dir
+                ).absolute()
+        except InvalidGitRepositoryError as err:
+            raise InvalidGitRepositoryError("No valid git repository found!") from err
+
+        if dir_path.absolute() != found_path:
+            logging.warning(
+                "Found .git/ in higher parent directory rather than provided in configuration."
+            )
+        return found_path
+
+    @field_validator("build_command_env", mode="after")
+    @classmethod
+    def remove_whitespace(cls, val: list[str]) -> list[str]:
+        return [entry.strip() for entry in val]
+
     @model_validator(mode="after")
-    def set_default_opts(self) -> RawConfig:
+    def set_default_opts(self) -> Self:
         # Set the default parser options for the given commit parser when no user input is given
         if not self.commit_parser_options and self.commit_parser:
             parser_opts_type = None
             # If the commit parser is a known one, pull the default options object from it
             if self.commit_parser in _known_commit_parsers:
+                # TODO: BREAKING CHANGE v10
+                # parser_opts_type = (
+                #     _known_commit_parsers[self.commit_parser]
+                #     .get_default_options()
+                #     .__class__
+                # )
                 parser_opts_type = _known_commit_parsers[
                     self.commit_parser
                 ].parser_options
             else:
-                # if its a custom parser, try to import it and pull the default options object type
-                custom_class = dynamic_import(self.commit_parser)
-                if hasattr(custom_class, "parser_options"):
-                    parser_opts_type = custom_class.parser_options
+                try:
+                    # if its a custom parser, try to import it and pull the default options object type
+                    custom_class = dynamic_import(self.commit_parser)
+                    # TODO: BREAKING CHANGE v10
+                    # parser_opts_type = custom_class.get_default_options().__class__
+                    if hasattr(custom_class, "parser_options"):
+                        parser_opts_type = custom_class.parser_options
+
+                except ModuleNotFoundError as err:
+                    raise ParserLoadError(
+                        str.join(
+                            "\n",
+                            [
+                                str(err),
+                                "Unable to import your custom parser! Check your configuration!",
+                            ],
+                        )
+                    ) from err
+
+                except AttributeError as err:
+                    raise ParserLoadError(
+                        str.join(
+                            "\n",
+                            [
+                                str(err),
+                                "Unable to find your custom parser class inside the given module.",
+                                "Check your configuration!",
+                            ],
+                        )
+                    ) from err
 
             # from either the custom opts class or the known parser opts class, create an instance
             if callable(parser_opts_type):
-                opts_obj = parser_opts_type()
+                opts_obj: Any = parser_opts_type()
                 # if the opts object is a dataclass, wrap it in a RootModel so it can be transformed to a Mapping
                 opts_obj = (
                     opts_obj if not is_dataclass(opts_obj) else RootModel(opts_obj)
@@ -226,12 +373,13 @@ def _recursive_getattr(obj: Any, path: str) -> Any:
 class RuntimeContext:
     _mask_attrs_: ClassVar[List[str]] = ["hvcs_client.token"]
 
-    repo: Repo
+    repo_dir: Path
     commit_parser: CommitParser[ParseResult, ParserOptions]
     version_translator: VersionTranslator
     major_on_zero: bool
     allow_zero_version: bool
     prerelease: bool
+    no_git_verify: bool
     assets: List[str]
     commit_author: Actor
     commit_message: str
@@ -243,6 +391,7 @@ class RuntimeContext:
     template_environment: Environment
     template_dir: Path
     build_command: Optional[str]
+    build_command_env: dict[str, str]
     dist_glob_patterns: Tuple[str, ...]
     upload_to_vcs_release: bool
     global_cli_options: GlobalCommandLineOptions
@@ -288,34 +437,70 @@ class RuntimeContext:
         return masker
 
     @classmethod
-    def from_raw_config(
-        cls, raw: RawConfig, repo: Repo, global_cli_options: GlobalCommandLineOptions
+    def from_raw_config(  # noqa: C901
+        cls, raw: RawConfig, global_cli_options: GlobalCommandLineOptions
     ) -> RuntimeContext:
         ##
         # credentials masking for logging
         masker = MaskingFilter(_use_named_masks=raw.logging_use_named_masks)
 
-        try:
-            active_branch = repo.active_branch.name
-        except TypeError as err:
-            raise NotAReleaseBranch(
-                "Detached HEAD state cannot match any release groups; "
-                "no release will be made"
-            ) from err
+        # Retrieve details from repository
+        with Repo(str(raw.repo_dir)) as git_repo:
+            try:
+                remote_url = raw.remote.url or git_repo.remote(raw.remote.name).url
+                active_branch = git_repo.active_branch.name
+            except ValueError as err:
+                raise MissingGitRemote(
+                    f"Unable to locate remote named '{raw.remote.name}'."
+                ) from err
+            except TypeError as err:
+                raise DetachedHeadGitError(
+                    "Detached HEAD state cannot match any release groups; "
+                    "no release will be made"
+                ) from err
 
         # branch-specific configuration
         branch_config = cls.select_branch_options(raw.branches, active_branch)
 
         # commit_parser
-        commit_parser_cls = (
-            _known_commit_parsers[raw.commit_parser]
-            if raw.commit_parser in _known_commit_parsers
-            else dynamic_import(raw.commit_parser)
-        )
+        try:
+            commit_parser_cls = (
+                _known_commit_parsers[raw.commit_parser]
+                if raw.commit_parser in _known_commit_parsers
+                else dynamic_import(raw.commit_parser)
+            )
+        except ModuleNotFoundError as err:
+            raise ParserLoadError(
+                str.join(
+                    "\n",
+                    [
+                        str(err),
+                        "Unable to import your custom parser! Check your configuration!",
+                    ],
+                )
+            ) from err
+        except AttributeError as err:
+            raise ParserLoadError(
+                str.join(
+                    "\n",
+                    [
+                        str(err),
+                        "Unable to find the parser class inside the given module",
+                    ],
+                )
+            ) from err
 
-        commit_parser = commit_parser_cls(
-            options=commit_parser_cls.parser_options(**raw.commit_parser_options)
-        )
+        commit_parser_opts_class = commit_parser_cls.parser_options
+        # TODO: Breaking change v10
+        # commit_parser_opts_class = commit_parser_cls.get_default_options().__class__
+        try:
+            commit_parser = commit_parser_cls(
+                options=commit_parser_opts_class(**raw.commit_parser_options)
+            )
+        except TypeError as err:
+            raise ParserLoadError(
+                str.join("\n", [str(err), f"Failed to initialize {raw.commit_parser}"])
+            ) from err
 
         # We always exclude PSR's own release commits from the Changelog
         # when parsing commits
@@ -365,44 +550,42 @@ class RuntimeContext:
 
             version_declarations.append(pd)
 
-        # hvcs_client
-        hvcs_client_cls = _known_hvcs[raw.remote.type]
-        raw_remote_url = raw.remote.url
-        resolved_remote_url = cls.resolve_from_env(raw_remote_url)
-        remote_url = (
-            resolved_remote_url
-            if resolved_remote_url is not None
-            else repo.remote(raw.remote.name).url
-        )
-
-        token = cls.resolve_from_env(raw.remote.token)
-        if (
-            isinstance(raw.remote.token, EnvConfigVar)
-            and not raw.remote.ignore_token_for_push
-            and not token
-        ):
-            log.warning(
-                "the token for the remote VCS is configured as stored in the %s "
-                "environment variable, but it is empty",
-                raw.remote.token.env,
-            )
-        elif not token:
+        # Provide warnings if the token is missing
+        if not raw.remote.token:
             log.debug("hvcs token is not set")
 
+            if not raw.remote.ignore_token_for_push:
+                log.warning("Token value is missing!")
+
+        # hvcs_client
+        hvcs_client_cls = _known_hvcs[raw.remote.type]
         hvcs_client = hvcs_client_cls(
             remote_url=remote_url,
-            hvcs_domain=cls.resolve_from_env(raw.remote.domain),
-            hvcs_api_domain=cls.resolve_from_env(raw.remote.api_domain),
-            token=token,
+            hvcs_domain=raw.remote.domain,
+            hvcs_api_domain=raw.remote.api_domain,
+            token=raw.remote.token,
+            allow_insecure=raw.remote.insecure,
         )
 
         # changelog_file
-        changelog_file = Path(raw.changelog.changelog_file).resolve()
+        changelog_file = Path(raw.changelog.changelog_file).expanduser().resolve()
 
-        template_dir = Path(repo.working_tree_dir or ".") / raw.changelog.template_dir
+        # Prevent path traversal attacks
+        if raw.repo_dir not in changelog_file.parents:
+            raise InvalidConfiguration(
+                "Changelog file destination must be inside of the repository directory."
+            )
+
+        template_dir = Path(raw.changelog.template_dir).expanduser().resolve()
+
+        # Prevent path traversal attacks
+        if raw.repo_dir not in template_dir.parents:
+            raise InvalidConfiguration(
+                "Template directory must be inside of the repository directory."
+            )
 
         template_environment = environment(
-            template_dir=raw.changelog.template_dir,
+            template_dir=template_dir,
             **raw.changelog.environment.model_dump(),
         )
 
@@ -411,13 +594,39 @@ class RuntimeContext:
             tag_format=raw.tag_format, prerelease_token=branch_config.prerelease_token
         )
 
+        build_cmd_env = {}
+
+        for i, env_var_def in enumerate(raw.build_command_env):
+            # creative hack to handle, missing =, but also = that then can be unpacked
+            # as the resulting parts array can be either 2 or 3 in length. it becomes 3
+            # with our forced empty value at the end which can be dropped
+            parts = [*env_var_def.split("=", 1), ""]
+            # removes any odd spacing around =, and extracts name=value
+            name, env_val = (part.strip() for part in parts[:2])
+
+            if not name:
+                # Skip when invalid format (ex. starting with = and no name)
+                logging.warning(
+                    "Skipping invalid build_command_env[%s] definition",
+                    i,
+                )
+                continue
+
+            if not env_val and env_var_def[-1] != "=":
+                # avoid the edge case that user wants to define a value as empty
+                # and don't autoresolve it
+                env_val = os.getenv(name, "")
+
+            build_cmd_env[name] = env_val
+
         self = cls(
-            repo=repo,
+            repo_dir=raw.repo_dir,
             commit_parser=commit_parser,
             version_translator=version_translator,
             major_on_zero=raw.major_on_zero,
             allow_zero_version=raw.allow_zero_version,
             build_command=raw.build_command,
+            build_command_env=build_cmd_env,
             version_declarations=tuple(version_declarations),
             hvcs_client=hvcs_client,
             changelog_file=changelog_file,
@@ -433,6 +642,7 @@ class RuntimeContext:
             upload_to_vcs_release=raw.publish.upload_to_vcs_release,
             global_cli_options=global_cli_options,
             masker=masker,
+            no_git_verify=raw.no_git_verify,
         )
         # credential masker
         self.apply_log_masking(self.masker)
