@@ -21,7 +21,7 @@ from tests.util import (
 )
 
 if TYPE_CHECKING:
-    from typing import Generator, Literal, Protocol, TypedDict, Union
+    from typing import Generator, Protocol, TypedDict, Union
 
     from semantic_release.hvcs import HvcsBase
 
@@ -29,11 +29,12 @@ if TYPE_CHECKING:
     from tests.fixtures.example_project import (
         ExProjectDir,
         UpdatePyprojectTomlFn,
+        UseCustomParserFn,
         UseHvcsFn,
         UseParserFn,
     )
 
-    CommitConvention = Literal["angular", "emoji", "scipy", "tag"]
+    CommitConvention = str
     VersionStr = str
     CommitMsg = str
     ChangelogTypeHeading = str
@@ -253,6 +254,7 @@ def build_configured_base_repo(  # noqa: C901
     use_emoji_parser: UseParserFn,
     use_scipy_parser: UseParserFn,
     use_tag_parser: UseParserFn,
+    use_custom_parser: UseCustomParserFn,
     example_git_https_url: str,
     update_pyproject_toml: UpdatePyprojectTomlFn,
 ) -> BuildRepoFn:
@@ -289,7 +291,7 @@ def build_configured_base_repo(  # noqa: C901
             elif commit_type == "tag":
                 use_tag_parser()
             else:
-                raise ValueError(f"Unknown parser name: {commit_type}")
+                use_custom_parser(commit_type)
 
             # Set HVCS configuration
             if hvcs_client_name == "github":
@@ -304,7 +306,7 @@ def build_configured_base_repo(  # noqa: C901
                 raise ValueError(f"Unknown HVCS client name: {hvcs_client_name}")
 
             # Create HVCS Client instance
-            hvcs = hvcs_class(example_git_https_url, hvcs_domain)
+            hvcs = hvcs_class(example_git_https_url, hvcs_domain=hvcs_domain)
 
             # Set tag format in configuration
             if tag_format_str is not None:
@@ -329,15 +331,13 @@ def simulate_default_changelog_creation() -> SimulateDefaultChangelogCreationFn:
         if version == "Unreleased":
             version_entry.append(f"## {version}\n")
         else:
-            version_entry.append(
-                # TODO: artificial newline in front due to template when no Unreleased changes exist
-                f"\n## v{version} ({TODAY_DATE_STR})\n"
-            )
+            version_entry.append(f"## v{version} ({TODAY_DATE_STR})\n")
 
         for section_def in version_def["changelog_sections"]:
             version_entry.append(f"### {section_def['section']}\n")
-            for i in section_def["i_commits"]:
-                version_entry.append(f"* {version_def['commits'][i]}\n")
+            version_entry.extend(
+                [f"* {version_def['commits'][i]}\n" for i in section_def["i_commits"]]
+            )
 
         return str.join("\n", version_entry)
 
@@ -353,7 +353,7 @@ def simulate_default_changelog_creation() -> SimulateDefaultChangelogCreationFn:
             version_entries.insert(0, build_version_entry(version, version_def))
 
         changelog_content = (
-            str.join("\n" * 3, [header, str.join("\n", list(version_entries))]).rstrip()
+            str.join("\n" * 2, [header, str.join("\n", list(version_entries))]).rstrip()
             + "\n"
         )
 
