@@ -12,6 +12,14 @@ from semantic_release.version.translator import VersionTranslator
 from semantic_release.version.version import Version
 
 from tests.const import ANGULAR_COMMITS_MINOR, COMMIT_MESSAGE
+from tests.fixtures import (
+    repo_w_github_flow_w_feature_release_channel_angular_commits,
+    repo_with_git_flow_and_release_channels_angular_commits,
+    repo_with_git_flow_angular_commits,
+    repo_with_no_tags_angular_commits,
+    repo_with_single_branch_and_prereleases_angular_commits,
+    repo_with_single_branch_angular_commits,
+)
 from tests.util import add_text_to_file
 
 # NOTE: not testing parser correctness here, just that the right commits end up
@@ -93,7 +101,7 @@ REPO_WITH_MAIN_AND_FEATURE_BRANCHES_EXPECTED_RELEASE_HISTORY = (
                 "unknown": [COMMIT_MESSAGE.format(version="0.2.0")],
             },
             Version.parse("0.3.0-beta.1"): {
-                "feature": ["feat: (feature) add some more text\n"],
+                "feature": ["feat(feature): add some more text\n"],
                 "unknown": [COMMIT_MESSAGE.format(version="0.3.0-beta.1")],
             },
         },
@@ -119,20 +127,20 @@ REPO_WITH_GIT_FLOW_EXPECTED_RELEASE_HISTORY = FakeReleaseHistoryElements(
             "unknown": [COMMIT_MESSAGE.format(version="1.0.0")],
         },
         Version.parse("1.1.0"): {
-            "feature": ["feat: (dev) add some more text\n"],
+            "feature": ["feat(dev): add some more text\n"],
             "unknown": [COMMIT_MESSAGE.format(version="1.1.0")],
         },
         Version.parse("1.1.1"): {
-            "fix": ["fix: (dev) add some more text\n"],
+            "fix": ["fix(dev): add some more text\n"],
             "unknown": [COMMIT_MESSAGE.format(version="1.1.1")],
         },
         Version.parse("1.2.0-alpha.1"): {
-            "feature": ["feat: (feature) add some more text\n"],
+            "feature": ["feat(feature): add some more text\n"],
             "unknown": [COMMIT_MESSAGE.format(version="1.2.0-alpha.1")],
         },
         Version.parse("1.2.0-alpha.2"): {
-            "feature": ["feat: (feature) add some more text\n"],
-            "fix": ["fix: (feature) add some missing text\n"],
+            "feature": ["feat(feature): add some more text\n"],
+            "fix": ["fix(feature): add some missing text\n"],
             "unknown": [COMMIT_MESSAGE.format(version="1.2.0-alpha.2")],
         },
     },
@@ -158,23 +166,23 @@ REPO_WITH_GIT_FLOW_AND_RELEASE_CHANNELS_EXPECTED_RELEASE_HISTORY = (
                 "unknown": [COMMIT_MESSAGE.format(version="1.0.0")],
             },
             Version.parse("1.1.0-rc.1"): {
-                "feature": ["feat: (dev) add some more text\n"],
+                "feature": ["feat(dev): add some more text\n"],
                 "unknown": [COMMIT_MESSAGE.format(version="1.1.0-rc.1")],
             },
             Version.parse("1.1.0-rc.2"): {
-                "fix": ["fix: (dev) add some more text\n"],
+                "fix": ["fix(dev): add some more text\n"],
                 "unknown": [COMMIT_MESSAGE.format(version="1.1.0-rc.2")],
             },
             Version.parse("1.1.0-alpha.1"): {
-                "feature": ["feat: (feature) add some more text\n"],
+                "feature": ["feat(feature): add some more text\n"],
                 "unknown": [COMMIT_MESSAGE.format(version="1.1.0-alpha.1")],
             },
             Version.parse("1.1.0-alpha.2"): {
-                "feature": ["feat: (feature) add some more text\n"],
+                "feature": ["feat(feature): add some more text\n"],
                 "unknown": [COMMIT_MESSAGE.format(version="1.1.0-alpha.2")],
             },
             Version.parse("1.1.0-alpha.3"): {
-                "fix": ["fix: (feature) add some more text\n"],
+                "fix": ["fix(feature): add some missing text\n"],
                 "unknown": [COMMIT_MESSAGE.format(version="1.1.0-alpha.3")],
             },
         },
@@ -187,27 +195,33 @@ REPO_WITH_GIT_FLOW_AND_RELEASE_CHANNELS_EXPECTED_RELEASE_HISTORY = (
     [
         # ANGULAR parser
         (
-            lazy_fixture("repo_with_no_tags_angular_commits"),
+            lazy_fixture(repo_with_no_tags_angular_commits.__name__),
             REPO_WITH_NO_TAGS_EXPECTED_RELEASE_HISTORY,
         ),
         (
-            lazy_fixture("repo_with_single_branch_angular_commits"),
+            lazy_fixture(repo_with_single_branch_angular_commits.__name__),
             REPO_WITH_SINGLE_BRANCH_EXPECTED_RELEASE_HISTORY,
         ),
         (
-            lazy_fixture("repo_with_single_branch_and_prereleases_angular_commits"),
+            lazy_fixture(
+                repo_with_single_branch_and_prereleases_angular_commits.__name__
+            ),
             REPO_WITH_SINGLE_BRANCH_AND_PRERELEASES_EXPECTED_RELEASE_HISTORY,
         ),
         (
-            lazy_fixture("repo_with_main_and_feature_branches_angular_commits"),
+            lazy_fixture(
+                repo_w_github_flow_w_feature_release_channel_angular_commits.__name__
+            ),
             REPO_WITH_MAIN_AND_FEATURE_BRANCHES_EXPECTED_RELEASE_HISTORY,
         ),
         (
-            lazy_fixture("repo_with_git_flow_angular_commits"),
+            lazy_fixture(repo_with_git_flow_angular_commits.__name__),
             REPO_WITH_GIT_FLOW_EXPECTED_RELEASE_HISTORY,
         ),
         (
-            lazy_fixture("repo_with_git_flow_and_release_channels_angular_commits"),
+            lazy_fixture(
+                repo_with_git_flow_and_release_channels_angular_commits.__name__
+            ),
             REPO_WITH_GIT_FLOW_AND_RELEASE_CHANNELS_EXPECTED_RELEASE_HISTORY,
         ),
     ],
@@ -231,15 +245,22 @@ def test_release_history(
         ),
     )
     for k in expected_release_history.released:
-        expected, actual = expected_release_history.released[k], released[k]["elements"]
-        actual_released_messages = [
-            res.commit.message for results in actual.values() for res in results
-        ]
-        assert all(
-            msg in actual_released_messages
-            for bucket in expected.values()
-            for msg in bucket
+        expected = expected_release_history.released[k]
+        actual = released[k]["elements"]
+        actual_released_messages = str.join(
+            "\n\n",
+            sorted(
+                [
+                    str(res.commit.message)
+                    for results in actual.values()
+                    for res in results
+                ]
+            ),
         )
+        expected_released_messages = str.join(
+            "\n\n", sorted([msg for bucket in expected.values() for msg in bucket])
+        )
+        assert expected_released_messages == actual_released_messages
 
     for commit_message in ANGULAR_COMMITS_MINOR:
         add_text_to_file(repo, file_in_repo)
@@ -249,17 +270,33 @@ def test_release_history(
     new_unreleased, new_released = ReleaseHistory.from_git_history(
         repo, translator, default_angular_parser
     )
-    actual_unreleased_messages = [
-        res.commit.message for results in new_unreleased.values() for res in results
-    ]
-    assert all(
-        msg in actual_unreleased_messages
-        for bucket in [
-            *expected_release_history.unreleased.values(),
-            ANGULAR_COMMITS_MINOR,
-        ]
-        for msg in bucket
+
+    actual_unreleased_messages = str.join(
+        "\n\n",
+        sorted(
+            [
+                str(res.commit.message)
+                for results in new_unreleased.values()
+                for res in results
+            ]
+        ),
     )
+
+    expected_unreleased_messages = str.join(
+        "\n\n",
+        sorted(
+            [
+                msg
+                for bucket in [
+                    ANGULAR_COMMITS_MINOR[::-1],
+                    *expected_release_history.unreleased.values(),
+                ]
+                for msg in bucket
+            ]
+        ),
+    )
+
+    assert expected_unreleased_messages == actual_unreleased_messages
     assert (
         new_released == released
     ), "something that shouldn't be considered release has been released"
@@ -268,12 +305,14 @@ def test_release_history(
 @pytest.mark.parametrize(
     "repo",
     [
-        lazy_fixture("repo_with_no_tags_angular_commits"),
-        lazy_fixture("repo_with_single_branch_angular_commits"),
-        lazy_fixture("repo_with_single_branch_and_prereleases_angular_commits"),
-        lazy_fixture("repo_with_main_and_feature_branches_angular_commits"),
-        lazy_fixture("repo_with_git_flow_angular_commits"),
-        lazy_fixture("repo_with_git_flow_and_release_channels_angular_commits"),
+        lazy_fixture(repo_with_no_tags_angular_commits.__name__),
+        lazy_fixture(repo_with_single_branch_angular_commits.__name__),
+        lazy_fixture(repo_with_single_branch_and_prereleases_angular_commits.__name__),
+        lazy_fixture(
+            repo_w_github_flow_w_feature_release_channel_angular_commits.__name__
+        ),
+        lazy_fixture(repo_with_git_flow_angular_commits.__name__),
+        lazy_fixture(repo_with_git_flow_and_release_channels_angular_commits.__name__),
     ],
 )
 def test_release_history_releases(repo, default_angular_parser):
@@ -300,6 +339,7 @@ def test_release_history_releases(repo, default_angular_parser):
             "committer": actor,
             "tagged_date": tagged_date,
             "elements": release_history.unreleased,
+            "version": new_version,
         },
         **release_history.released,
     }
@@ -308,12 +348,14 @@ def test_release_history_releases(repo, default_angular_parser):
 @pytest.mark.parametrize(
     "repo",
     [
-        lazy_fixture("repo_with_no_tags_angular_commits"),
-        lazy_fixture("repo_with_single_branch_angular_commits"),
-        lazy_fixture("repo_with_single_branch_and_prereleases_angular_commits"),
-        lazy_fixture("repo_with_main_and_feature_branches_angular_commits"),
-        lazy_fixture("repo_with_git_flow_angular_commits"),
-        lazy_fixture("repo_with_git_flow_and_release_channels_angular_commits"),
+        lazy_fixture(repo_with_no_tags_angular_commits.__name__),
+        lazy_fixture(repo_with_single_branch_angular_commits.__name__),
+        lazy_fixture(repo_with_single_branch_and_prereleases_angular_commits.__name__),
+        lazy_fixture(
+            repo_w_github_flow_w_feature_release_channel_angular_commits.__name__
+        ),
+        lazy_fixture(repo_with_git_flow_angular_commits.__name__),
+        lazy_fixture(repo_with_git_flow_and_release_channels_angular_commits.__name__),
     ],
 )
 def test_all_matching_repo_tags_are_released(repo, default_angular_parser):
